pub struct OplockTable {
held: Mutex<HashMap<String, OplockHolder>>,
}Expand description
Server-wide oplock table: at most one exclusive oplock per file path.
Fields
held: Mutex<HashMap<String, OplockHolder>>Implementations
Sourceimpl OplockTable
impl OplockTable
Sourcepub fn grant(&self, path: &str, holder: OplockHolder) -> bool
pub fn grant(&self, path: &str, holder: OplockHolder) -> bool
Grant an exclusive oplock on path if none is held.
Sourcepub fn take(&self, path: &str) -> Option<OplockHolder>
pub fn take(&self, path: &str) -> Option<OplockHolder>
Remove and return the current holder of path, if any.
Sourcepub fn release(&self, path: &str, owner: LockOwner) -> Option<OplockHolder>
pub fn release(&self, path: &str, owner: LockOwner) -> Option<OplockHolder>
Drop the oplock held by owner on path (on close), returning it.
Sourcepub fn release_session(&self, session_id: u64)
pub fn release_session(&self, session_id: u64)
Drop every oplock held by any open of session_id.